==> editorial_access_manager-1.1.5.tar.gz: editorial_access_manager/tests/src/Functional/EditorialAccessManagerAccessTest.php <==
<?php

namespace Drupal\Tests\editorial_access_manager\Functional;

/**
 * Test that proper permissions grants access to editorial manager access page.
 */
class EditorialAccessManagerAccessTest extends EditorialAccessManagerTestsBase {

  /**
   * List of users and entities to check its access.
   */
  public function dataProviderTestAccess() {
    return [
      [
        'Translator manager, Entity test mul: Access allowed',
        'Test entity with translation assignment access',
        'translator_manager',
        200,
      ],
      [
        'Translator Entity Test mul manager, Entity test mul: Access allowed',
        'Test entity with translation assignment access',
        'translator_entity_test_mul_manager',
        200,
      ],
      [
        'Translator Entity Test mul translation manager, Entity test mul: Access allowed',
        'Test entity with translation assignment access',
        'translator_entity_test_mul_translation_manager',
        200,
      ],
      [
        'Translator Node manager, Entity test mul: Access denied',
        'Test entity with translation assignment access',
        'translator_node_manager',
        403,
      ],
      [
        'Translator manager, Entity test mul other bundle: Access denied',
        'Test entity without translation assignment access',
        'translator_manager',
        403,
      ],
      [
        'Translator manager, Node: Access denied',
        'Test node without translation assignment access',
        'translator_manager',
        403,
        'node',
      ],
      [
        'Anonymous, Entity test mul: Access denied',
        'Test entity with translation assignment access',
        'anonymous',
        403,
      ],
      [
        'Anonymous, Entity test mul other bundle: Access denied',
        'Test entity without translation assignment access',
        'anonymous',
        403,
      ],
      [
        'Anonymous, Node: Access denied',
        'Test node without translation assignment access',
        'anonymous',
        403,
        'node',
      ],
      [
        'Assignable Translator, Entity test mul: Access denied',
        'Test entity with translation assignment access',
        'assignable_translator',
        403,
      ],
      [
        'Assignable Translator, Entity test mul other bundle: Access denied',
        'Test entity without translation assignment access',
        'assignable_translator',
        403,
      ],
      [
        'Assignable Translator, Node: Access denied',
        'Test node without translation assignment access',
        'assignable_translator',
        403,
        'node',
      ],
      [
        'Assignable Entity Test With Bundle, Entity test mul: Access denied',
        'Test entity with translation assignment access',
        'assignable_entity_test_mul',
        403,
      ],
      [
        'Assignable Entity Test With Bundle, Entity test mul other bundle: Access denied',
        'Test entity without translation assignment access',
        'assignable_entity_test_mul',
        403,
      ],
      [
        'Assignable Entity Test With Bundle, Node: Access denied',
        'Test node without translation assignment access',
        'assignable_entity_test_mul',
        403,
        'node',
      ],
      [
        'Assignable Node, Entity test mul: Access denied',
        'Test entity with translation assignment access',
        'assignable_node',
        403,
      ],
      [
        'Assignable Node, Entity test mul other bundle: Access denied',
        'Test entity without translation assignment access',
        'assignable_node',
        403,
      ],
      [
        'Assignable Node, Node: Access denied',
        'Test node without translation assignment access',
        'assignable_node',
        403,
        'node',
      ],
    ];
  }

  /**
   * Test that users can access only with the correct permissions.
   *
   * Only these permissions must allow synchronizing an entity:
   *  - synchronize any entity translation
   *  - synchronize <entity-type> translation.
   *
   * @dataProvider dataProviderTestAccess
   */
  public function testAccess(string $label, string $entity_title, string $user_name, int $expected_status_code, string $entity_type = NULL) {
    $user = $this->getUserByName($user_name);
    $this->drupalLogin($user);
    $entity = $this->drupalGetEntityTestByLabel($entity_title, $entity_type);
    $this->drupalGet($entity->toUrl('drupal:editorial-access-management'));
    $this->assertEquals($expected_status_code, $this->getSession()->getStatusCode(), $label);
    $this->drupalLogout();
  }

  /**
   * {@inheritdoc}
   */
  protected function getConfiguredEntityTypes() : array {
    return [
      'node' => [],
      'entity_test_mul_with_bundle' => [
        'entity_test_mul_with_bundle' => 'entity_test_mul_with_bundle',
      ],
    ];
  }

}

==> editorial_access_manager-1.1.6.tar.gz: editorial_access_manager/tests/src/Functional/EditorialAccessManagerAccessTest.php <==
<?php

namespace Drupal\Tests\editorial_access_manager\Functional;

/**
 * Test that proper permissions grants access to editorial manager access page.
 */
class EditorialAccessManagerAccessTest extends EditorialAccessManagerTestsBase {

  /**
   * List of users and entities to check its access.
   */
  public function dataProviderTestAccess() {
    return [
      [
        'Translator manager, Entity test mul: Access allowed',
        'Test entity with translation assignment access',
        'translator_manager',
        200,
      ],
      [
        'Translator Entity Test mul manager, Entity test mul: Access allowed',
        'Test entity with translation assignment access',
        'translator_entity_test_mul_manager',
        200,
      ],
      [
        'Translator Entity Test mul translation manager, Entity test mul: Access allowed',
        'Test entity with translation assignment access',
        'translator_entity_test_mul_translation_manager',
        200,
      ],
      [
        'Translator Node manager, Entity test mul: Access denied',
        'Test entity with translation assignment access',
        'translator_node_manager',
        403,
      ],
      [
        'Translator manager, Entity test mul other bundle: Access denied',
        'Test entity without translation assignment access',
        'translator_manager',
        403,
      ],
      [
        'Translator manager, Node: Access denied',
        'Test node without translation assignment access',
        'translator_manager',
        403,
        'node',
      ],
      [
        'Anonymous, Entity test mul: Access denied',
        'Test entity with translation assignment access',
        'anonymous',
        403,
      ],
      [
        'Anonymous, Entity test mul other bundle: Access denied',
        'Test entity without translation assignment access',
        'anonymous',
        403,
      ],
      [
        'Anonymous, Node: Access denied',
        'Test node without translation assignment access',
        'anonymous',
        403,
        'node',
      ],
      [
        'Assignable Translator, Entity test mul: Access denied',
        'Test entity with translation assignment access',
        'assignable_translator',
        403,
      ],
      [
        'Assignable Translator, Entity test mul other bundle: Access denied',
        'Test entity without translation assignment access',
        'assignable_translator',
        403,
      ],
      [
        'Assignable Translator, Node: Access denied',
        'Test node without translation assignment access',
        'assignable_translator',
        403,
        'node',
      ],
      [
        'Assignable Entity Test With Bundle, Entity test mul: Access denied',
        'Test entity with translation assignment access',
        'assignable_entity_test_mul',
        403,
      ],
      [
        'Assignable Entity Test With Bundle, Entity test mul other bundle: Access denied',
        'Test entity without translation assignment access',
        'assignable_entity_test_mul',
        403,
      ],
      [
        'Assignable Entity Test With Bundle, Node: Access denied',
        'Test node without translation assignment access',
        'assignable_entity_test_mul',
        403,
        'node',
      ],
      [
        'Assignable Node, Entity test mul: Access denied',
        'Test entity with translation assignment access',
        'assignable_node',
        403,
      ],
      [
        'Assignable Node, Entity test mul other bundle: Access denied',
        'Test entity without translation assignment access',
        'assignable_node',
        403,
      ],
      [
        'Assignable Node, Node: Access denied',
        'Test node without translation assignment access',
        'assignable_node',
        403,
        'node',
      ],
    ];
  }

  /**
   * Test that users can access only with the correct permissions.
   *
   * Only these permissions must allow synchronizing an entity:
   *  - synchronize any entity translation
   *  - synchronize <entity-type> translation.
   *
   * @dataProvider dataProviderTestAccess
   */
  public function testAccess(string $label, string $entity_title, string $user_name, int $expected_status_code, string $entity_type = NULL) {
    $user = $this->getUserByName($user_name);
    $this->drupalLogin($user);
    $entity = $this->drupalGetEntityTestByLabel($entity_title, $entity_type);
    $this->drupalGet($entity->toUrl('drupal:editorial-access-management'));
    $this->assertEquals($expected_status_code, $this->getSession()->getStatusCode(), $label);
    $this->drupalLogout();
  }

  /**
   * {@inheritdoc}
   */
  protected function getConfiguredEntityTypes() : array {
    return [
      'node' => [],
      'entity_test_mul_with_bundle' => [
        [
          'bundle' => 'entity_test_mul_with_bundle',
        ],
      ],
    ];
  }

}
